@@ -3,7 +3,8 @@ from typing import Optional
 
 from survey.mixins.data import DataMixin
 from survey.mixins.data_types.discrete_1d_mixin import Discrete1dMixin
-from survey.mixins.data_validation.count_validation_mixin import CountValidationMixin
+from survey.mixins.data_validation.count_validation_mixin import \
+    CountValidationMixin
 from survey.mixins.named import NamedMixin
 from survey.attributes._abstract.respondent_attribute import RespondentAttribute
 
@@ -22,7 +23,7 @@ class CountAttribute(
         """
         Create a new Count Attribute.
 
-        :param name: A shorthand name for the attribute.
+        :param name: A pythonic name for the attribute.
         :param text: The text of the attribute.
         :param data: Optional pandas Series of responses.
         """
