@@ -1,20 +1,24 @@
 from typing import Dict, List, Optional
 
 from survey.custom_types import NumericalAttribute
-from survey.mixins.containers.attribute_container_mixin import AttributeContainerMixin
+from survey.mixins.containers.attribute_container_mixin import \
+    AttributeContainerMixin
 
 
 class NumericalAttributeGroup(AttributeContainerMixin, object):
 
     def __init__(self, attributes: Dict[str, NumericalAttribute] = None):
 
-        self._questions: List[NumericalAttribute] = [a for a in attributes.values()]
+        self._questions: List[NumericalAttribute] = [
+            a for a in attributes.values()
+        ]
         self._item_dict: Dict[str, NumericalAttribute] = attributes
         for property_name, attribute in attributes.items():
             try:
                 setattr(self, property_name, attribute)
             except:
-                print(f'Warning - could not set dynamic property for Attribute: {attribute}')
+                print(f'Warning - could not set dynamic property'
+                      f' for Attribute: {attribute}')
 
     def question(self, name: str) -> Optional[NumericalAttribute]:
         """
