@@ -1,15 +1,14 @@
-from typing import List
+from typing import Callable, Optional
 
 from numpy import nan
 from pandas import Series, isnull
 from pandas.core.dtypes.inference import is_number
 
-from survey.constants import CATEGORY_SPLITTER
-
 
 class DataMixin(object):
 
-    _data: Series
+    _data: Optional[Series]
+    _validate_data: Callable[[Series], None]
 
     def _set_data(self, data: Series):
 
@@ -30,8 +29,9 @@ class DataMixin(object):
 
 class CategoricalDataMixin(object):
 
-    _data: Series
+    _data: Optional[Series]
     name: str
+    _validate_data: Callable[[Series], None]
 
     def _set_data(self, data: Series):
         if data is not None:
