@@ -1,4 +1,6 @@
 from itertools import product
+from typing import List, Optional, Dict, Tuple, Union, TYPE_CHECKING
+
 from matplotlib.axes import Axes
 from matplotlib.patches import Patch
 from mpl_format.axes.axes_formatter import AxesFormatter
@@ -6,8 +8,7 @@ from mpl_format.axes.axis_utils import new_axes
 from mpl_format.text.text_utils import wrap_text, map_text
 from numpy import nan
 from pandas import Series, DataFrame, pivot_table, concat, isnull, notnull
-from probability.distributions import BetaBinomial
-from typing import List, Optional, Dict, Tuple, Union, TYPE_CHECKING
+from probability.distributions import BetaBinomialConjugate
 
 from survey.constants import CATEGORY_SPLITTER
 from survey.mixins.data import DataMixin
@@ -38,7 +39,7 @@ class MultiChoiceQuestion(
         """
         Create a new multiple choice question.
 
-        :param name: A shorthand name for the question.
+        :param name: A pythonic name for the question.
         :param text: The text asked in the question.
         :param categories: The list of possible choices.
         :param ordered: Whether the choices passed are ordered (low to high).
@@ -50,15 +51,22 @@ class MultiChoiceQuestion(
         self._ordered = ordered
 
     def _validate_data(self, data: Series):
+
         unique = set([selection for ix, item in data.dropna().iteritems()
                      for selection in item.split(CATEGORY_SPLITTER)
                      if notnull(selection)])
         errors = []
+        error_vals = []
         for unique_val in unique:
             if unique_val not in self._categories:
-                errors.append(f'"{unique_val}" is not in categories.')
+                error_vals.append(unique_val)
+                errors.append(f'"{unique_val}" is not in categories'
+                              f' for question "{self.text}".')
         if errors:
-            raise ValueError('\n'.join(errors))
+            raise ValueError(
+                '\n'.join(errors) +
+                '\nList of values:\n' + '\n'.join(error_vals)
+            )
 
     def make_features(self, answers: Series = None, drop_na: bool = True,
                       naming: str = '{{name}}: {{choice}}',
@@ -138,8 +146,10 @@ class MultiChoiceQuestion(
             results.append({
                 'category': category,
                 'p': (
-                    BetaBinomial(1, 1, n_one, m_one).posterior() >
-                    BetaBinomial(1, 1, n_rest, m_rest).posterior()
+                    BetaBinomialConjugate(
+                        alpha=1, beta=1, n=n_one, k=m_one).posterior() >
+                    BetaBinomialConjugate(
+                        alpha=1, beta=1, n=n_rest, k=m_rest).posterior()
                 )
             })
         return DataFrame(results).set_index('category')['p']
@@ -160,8 +170,10 @@ class MultiChoiceQuestion(
                 'category_1': category_1,
                 'category_2': category_2,
                 'p': (
-                        BetaBinomial(1, 1, n, m_1).posterior() >
-                        BetaBinomial(1, 1, n, m_2).posterior()
+                    BetaBinomialConjugate(
+                        alpha=1, beta=1, n=n, k=m_1).posterior() >
+                    BetaBinomialConjugate(
+                        alpha=1, beta=1, n=n, k=m_2).posterior()
                 )
             })
         results_data = DataFrame(results)
@@ -177,12 +189,13 @@ class MultiChoiceQuestion(
                           significance: bool = False,
                           sig_colors: Tuple[str, str] = ('#00ff00', '#ff0000'),
                           label_mappings: Optional[Dict[str, str]] = None,
-                          title: Optional[str] = None,
                           grid: bool = False,
                           max_axis_label_chars: Optional[int] = None,
+                          title: Optional[str] = None,
                           x_label: Optional[str] = None,
                           y_label: Optional[str] = None,
-                          ax: Optional[Axes] = None) -> Axes:
+                          ax: Optional[Axes] = None,
+                          **kwargs) -> Axes:
         """
         Plot the distribution of answers to the Question.
 
@@ -197,10 +210,10 @@ class MultiChoiceQuestion(
         :param sig_colors: Tuple of (high, low) colors for highlighting
                            significance.
         :param label_mappings: Optional dict of replacements for labels.
-        :param title: Optional title for the plot.
         :param grid: Whether to show a plot grid or not.
         :param max_axis_label_chars: Maximum number of characters in axis labels
                                      before wrapping.
+        :param title: Axes title.
         :param x_label: Label for the x-axis.
         :param y_label: Label for the y-axis.
         """
@@ -209,6 +222,12 @@ class MultiChoiceQuestion(
             raise ValueError('No data!')
         if len(data) == 0:
             return ax
+        if title is None:
+            title = self.text
+        if x_label is None:
+            x_label = self.name if not transpose else '# Respondents'
+        if y_label is None:
+            y_label = '# Respondents' if not transpose else self.name
         features = self.make_features(
             answers=data, drop_na=drop_na, naming='{{choice}}'
         )
@@ -236,7 +255,8 @@ class MultiChoiceQuestion(
             line_width = [2 if ec != color else None for ec in edge_color]
 
         item_counts.plot(kind=plot_type, ax=ax, color=color,
-                         edgecolor=edge_color, linewidth=line_width)
+                         edgecolor=edge_color, linewidth=line_width,
+                         **kwargs)
 
         # add percentages
         item_pcts = 100 * item_counts.div(len(features))
@@ -521,8 +541,10 @@ class MultiChoiceQuestion(
             results.append({
                 'category': category,
                 'p': (
-                    BetaBinomial(1, 1, n_self, m_self).posterior() >
-                    BetaBinomial(1, 1, n_other, m_other).posterior()
+                    BetaBinomialConjugate(
+                        alpha=1, beta=1, n=n_self, k=m_self).posterior() >
+                    BetaBinomialConjugate(
+                        alpha=1, beta=1, n=n_other, k=m_other).posterior()
                 )
             })
         return DataFrame(results).set_index('category')['p']
