@@ -3,7 +3,8 @@ from typing import Optional
 
 from survey.mixins.data import DataMixin
 from survey.mixins.data_types.continuous_1d_mixin import Continuous1dMixin
-from survey.mixins.data_validation.positive_measure_validation_mixin import PositiveMeasureValidationMixin
+from survey.mixins.data_validation.positive_measure_validation_mixin import \
+    PositiveMeasureValidationMixin
 from survey.mixins.named import NamedMixin
 from survey.questions._abstract.question import Question
 
@@ -22,7 +23,7 @@ class PositiveMeasureQuestion(
         """
         Create a new Positive Measure question.
 
-        :param name: A shorthand name for the question.
+        :param name: A pythonic name for the question.
         :param text: The text of the question.
         :param data: Optional pandas Series of responses.
         """
